# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.label_field import LabelField

class TestLabelField(unittest.TestCase):
    """LabelField unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LabelField:
        """Test LabelField
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LabelField`
        """
        model = LabelField()
        if include_optional:
            return LabelField(
                date_string = [
                    datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date()
                    ],
                id = '',
                integer = [
                    ''
                    ],
                kind = '',
                selection = [
                    ''
                    ],
                text = [
                    ''
                    ],
                user = [
                    google_drive_ti.models.user.User(
                        display_name = '', 
                        email_address = '', 
                        kind = 'drive#user', 
                        me = True, 
                        permission_id = '', 
                        photo_link = '', )
                    ],
                value_type = ''
            )
        else:
            return LabelField(
        )
        """

    def testLabelField(self):
        """Test LabelField"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
