# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.about import About

class TestAbout(unittest.TestCase):
    """About unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> About:
        """Test About
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `About`
        """
        model = About()
        if include_optional:
            return About(
                app_installed = True,
                can_create_drives = True,
                can_create_team_drives = True,
                drive_themes = [
                    google_drive_ti.models.about_drive_themes_inner.About_driveThemes_inner(
                        background_image_link = '', 
                        color_rgb = '', 
                        id = '', )
                    ],
                export_formats = None,
                folder_color_palette = [
                    ''
                    ],
                import_formats = None,
                kind = 'drive#about',
                max_import_sizes = None,
                max_upload_size = '',
                storage_quota = google_drive_ti.models.about_storage_quota.About_storageQuota(
                    limit = '', 
                    usage = '', 
                    usage_in_drive = '', 
                    usage_in_drive_trash = '', ),
                team_drive_themes = [
                    google_drive_ti.models.about_team_drive_themes_inner.About_teamDriveThemes_inner(
                        background_image_link = '', 
                        color_rgb = '', 
                        id = '', )
                    ],
                user = google_drive_ti.models.user.User(
                    display_name = '', 
                    email_address = '', 
                    kind = 'drive#user', 
                    me = True, 
                    permission_id = '', 
                    photo_link = '', )
            )
        else:
            return About(
        )
        """

    def testAbout(self):
        """Test About"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
