# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.api.teamdrives_api import TeamdrivesApi


class TestTeamdrivesApi(unittest.TestCase):
    """TeamdrivesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TeamdrivesApi()

    def tearDown(self) -> None:
        pass

    def test_drive_teamdrives_create(self) -> None:
        """Test case for drive_teamdrives_create

        """
        pass

    def test_drive_teamdrives_delete(self) -> None:
        """Test case for drive_teamdrives_delete

        """
        pass

    def test_drive_teamdrives_get(self) -> None:
        """Test case for drive_teamdrives_get

        """
        pass

    def test_drive_teamdrives_list(self) -> None:
        """Test case for drive_teamdrives_list

        """
        pass

    def test_drive_teamdrives_update(self) -> None:
        """Test case for drive_teamdrives_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
