# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.api.about_api import AboutApi


class TestAboutApi(unittest.TestCase):
    """AboutApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AboutApi()

    def tearDown(self) -> None:
        pass

    def test_drive_about_get(self) -> None:
        """Test case for drive_about_get

        """
        pass


if __name__ == '__main__':
    unittest.main()
