# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.generated_ids import GeneratedIds

class TestGeneratedIds(unittest.TestCase):
    """GeneratedIds unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GeneratedIds:
        """Test GeneratedIds
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GeneratedIds`
        """
        model = GeneratedIds()
        if include_optional:
            return GeneratedIds(
                ids = [
                    ''
                    ],
                kind = 'drive#generatedIds',
                space = ''
            )
        else:
            return GeneratedIds(
        )
        """

    def testGeneratedIds(self):
        """Test GeneratedIds"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
