# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ResolveAccessProposalRequest(BaseModel):
    """
    Request message for resolving an AccessProposal on a file.
    """ # noqa: E501
    action: Optional[StrictStr] = Field(default=None, description="Required. The action to take on the AccessProposal.")
    role: Optional[List[StrictStr]] = Field(default=None, description="Optional. The roles the approver has allowed, if any. Note: This field is required for the `ACCEPT` action.")
    send_notification: Optional[StrictBool] = Field(default=None, description="Optional. Whether to send an email to the requester when the AccessProposal is denied or accepted.", alias="sendNotification")
    view: Optional[StrictStr] = Field(default=None, description="Optional. Indicates the view for this access proposal. This should only be set when the proposal belongs to a view. `published` is the only supported value.")
    __properties: ClassVar[List[str]] = ["action", "role", "sendNotification", "view"]

    @field_validator('action')
    def action_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['ACTION_UNSPECIFIED', 'ACCEPT', 'DENY']):
            raise ValueError("must be one of enum values ('ACTION_UNSPECIFIED', 'ACCEPT', 'DENY')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ResolveAccessProposalRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ResolveAccessProposalRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "action": obj.get("action"),
            "role": obj.get("role"),
            "sendNotification": obj.get("sendNotification"),
            "view": obj.get("view")
        })
        return _obj


