# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.access_proposal import AccessProposal

class TestAccessProposal(unittest.TestCase):
    """AccessProposal unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AccessProposal:
        """Test AccessProposal
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AccessProposal`
        """
        model = AccessProposal()
        if include_optional:
            return AccessProposal(
                create_time = '',
                file_id = '',
                proposal_id = '',
                recipient_email_address = '',
                request_message = '',
                requester_email_address = '',
                roles_and_views = [
                    google_drive_ti.models.access_proposal_role_and_view.AccessProposalRoleAndView(
                        role = '', 
                        view = '', )
                    ]
            )
        else:
            return AccessProposal(
        )
        """

    def testAccessProposal(self):
        """Test AccessProposal"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
