# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.file_capabilities import FileCapabilities

class TestFileCapabilities(unittest.TestCase):
    """FileCapabilities unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FileCapabilities:
        """Test FileCapabilities
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FileCapabilities`
        """
        model = FileCapabilities()
        if include_optional:
            return FileCapabilities(
                can_accept_ownership = True,
                can_add_children = True,
                can_add_folder_from_another_drive = True,
                can_add_my_drive_parent = True,
                can_change_copy_requires_writer_permission = True,
                can_change_security_update_enabled = True,
                can_change_viewers_can_copy_content = True,
                can_comment = True,
                can_copy = True,
                can_delete = True,
                can_delete_children = True,
                can_download = True,
                can_edit = True,
                can_list_children = True,
                can_modify_content = True,
                can_modify_content_restriction = True,
                can_modify_editor_content_restriction = True,
                can_modify_labels = True,
                can_modify_owner_content_restriction = True,
                can_move_children_out_of_drive = True,
                can_move_children_out_of_team_drive = True,
                can_move_children_within_drive = True,
                can_move_children_within_team_drive = True,
                can_move_item_into_team_drive = True,
                can_move_item_out_of_drive = True,
                can_move_item_out_of_team_drive = True,
                can_move_item_within_drive = True,
                can_move_item_within_team_drive = True,
                can_move_team_drive_item = True,
                can_read_drive = True,
                can_read_labels = True,
                can_read_revisions = True,
                can_read_team_drive = True,
                can_remove_children = True,
                can_remove_content_restriction = True,
                can_remove_my_drive_parent = True,
                can_rename = True,
                can_share = True,
                can_trash = True,
                can_trash_children = True,
                can_untrash = True
            )
        else:
            return FileCapabilities(
        )
        """

    def testFileCapabilities(self):
        """Test FileCapabilities"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
