# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.drive_capabilities import DriveCapabilities

class TestDriveCapabilities(unittest.TestCase):
    """DriveCapabilities unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DriveCapabilities:
        """Test DriveCapabilities
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DriveCapabilities`
        """
        model = DriveCapabilities()
        if include_optional:
            return DriveCapabilities(
                can_add_children = True,
                can_change_copy_requires_writer_permission_restriction = True,
                can_change_domain_users_only_restriction = True,
                can_change_drive_background = True,
                can_change_drive_members_only_restriction = True,
                can_change_sharing_folders_requires_organizer_permission_restriction = True,
                can_comment = True,
                can_copy = True,
                can_delete_children = True,
                can_delete_drive = True,
                can_download = True,
                can_edit = True,
                can_list_children = True,
                can_manage_members = True,
                can_read_revisions = True,
                can_rename = True,
                can_rename_drive = True,
                can_reset_drive_restrictions = True,
                can_share = True,
                can_trash_children = True
            )
        else:
            return DriveCapabilities(
        )
        """

    def testDriveCapabilities(self):
        """Test DriveCapabilities"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
