# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.permission import Permission

class TestPermission(unittest.TestCase):
    """Permission unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Permission:
        """Test Permission
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Permission`
        """
        model = Permission()
        if include_optional:
            return Permission(
                allow_file_discovery = True,
                deleted = True,
                display_name = '',
                domain = '',
                email_address = '',
                expiration_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                kind = 'drive#permission',
                pending_owner = True,
                permission_details = [
                    google_drive_ti.models.permission_permission_details_inner.Permission_permissionDetails_inner(
                        inherited = True, 
                        inherited_from = '', 
                        permission_type = '', 
                        role = '', )
                    ],
                photo_link = '',
                role = '',
                team_drive_permission_details = [
                    google_drive_ti.models.permission_team_drive_permission_details_inner.Permission_teamDrivePermissionDetails_inner(
                        inherited = True, 
                        inherited_from = '', 
                        role = '', 
                        team_drive_permission_type = '', )
                    ],
                type = '',
                view = ''
            )
        else:
            return Permission(
        )
        """

    def testPermission(self):
        """Test Permission"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
